From 7ee587c057bb1cb3c0911cba657af958bf5bbf7b Mon Sep 17 00:00:00 2001
From: Kris Jusiak
Date: Tue, 4 Feb 2025 11:44:24 +0000
Subject: [PATCH] :arrow_up: v2.3.0
---
CMakeLists.txt | 2 +-
README.md | 6 +++---
include/boost/ut.hpp | 6 +++---
3 files changed, 7 insertions(+), 7 deletions(-)
diff --git a/CMakeLists.txt b/CMakeLists.txt
index d9491e88..d25b65dd 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -7,7 +7,7 @@
cmake_minimum_required(VERSION 3.21...3.25)
project(
ut
- VERSION 2.1.1
+ VERSION 2.3.0
LANGUAGES CXX
)
diff --git a/README.md b/README.md
index 8b2b60d6..224e42c2 100644
--- a/README.md
+++ b/README.md
@@ -190,7 +190,7 @@ target_link_libraries(my_test PRIVATE Boost::ut)
> [Optional] [Conan](https://conan.io) integration
The [boost-ext-ut](https://conan.io/center/boost-ext-ut) package is available from [Conan Center](https://conan.io/center/).
-Just include it in your project's Conanfile with `boost-ext-ut/2.1.1`.
+Just include it in your project's Conanfile with `boost-ext-ut/2.3.0`.
@@ -1255,7 +1255,7 @@ int main() {
```cpp
export module boost.ut; /// __cpp_modules
-namespace boost::inline ext::ut::inline v2_1_1 {
+namespace boost::inline ext::ut::inline v2_3_0 {
/**
* Represents test suite object
*/
@@ -1616,7 +1616,7 @@ namespace boost::inline ext::ut::inline v2_1_1 {
| Option | Description | Example |
|-|-|-|
-| `BOOST_UT_VERSION` | Current version | `2'1'1` |
+| `BOOST_UT_VERSION` | Current version | `2'3'0` |
diff --git a/include/boost/ut.hpp b/include/boost/ut.hpp
index 4dfac0ef..96522af3 100644
--- a/include/boost/ut.hpp
+++ b/include/boost/ut.hpp
@@ -53,7 +53,7 @@ export import std;
#elif not defined(__cpp_static_assert)
#error "[Boost::ext].UT requires support for static assert";
#else
-#define BOOST_UT_VERSION 2'1'1
+#define BOOST_UT_VERSION 2'3'0
#if defined(__has_builtin) and defined(__GNUC__) and (__GNUC__ < 10) and \
not defined(__clang__)
@@ -106,7 +106,7 @@ struct unique_name_for_auto_detect_prefix_and_suffix_length_0123456789_struct_ {
};
BOOST_UT_EXPORT
-namespace boost::inline ext::ut::inline v2_1_1 {
+namespace boost::inline ext::ut::inline v2_3_0 {
namespace utility {
template
class function;
@@ -3342,7 +3342,7 @@ using operators::operator not;
using operators::operator|;
using operators::operator/;
using operators::operator>>;
-} // namespace boost::inline ext::ut::inline v2_1_1
+} // namespace boost::inline ext::ut::inline v2_3_0
#if (defined(__GNUC__) || defined(__clang__) || defined(__INTEL_COMPILER)) && \
!defined(__EMSCRIPTEN__)